/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: BUSL-1.1
 */

export { isAdvancedSecret } from 'core/utils/advanced-secret';
